@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 """Unwind short-links e.g. bit.ly, t.co etc to their canonical links"""
+from __future__ import unicode_literals
 import requests
 
 
@@ -24,5 +25,5 @@ def follow_shortlinks(shortlinks):
 
 
 if __name__ == "__main__":
-    shortlinks = ['http://t.co/8o0z9BbEMu', u'http://bbc.in/16dClPF']
+    shortlinks = ['http://t.co/8o0z9BbEMu', 'http://bbc.in/16dClPF']
     print follow_shortlinks(shortlinks)
